********************************************************************************
Citing
********************************************************************************

If you use COMPAS TIMBER in a project, please use the following citation:

.. code-block:: none

    @misc{compas_timber,
        title  = {{COMPAS_TIMBER}: A library for design and fabrication of timber structures.},
        author = {Apolinarska, Aleksandra Anna and Kasirer, Chen and Casas, Gonzalo and many others},
        note   = {https://github.com/gramaziokohler/compas_timber},
        year   = {2022-2024},
        doi    = {10.5281/zenodo.7934267},
        url    = {},
    }

Authors
=======

* Aleksandra Anna Apolinarska <apolinarska@arch.ethz.ch> `@funkchaser <https://github.com/funkchaser>`_
* Chen Kasirer <kasirer@arch.ethz.ch> `@chenkasirer <https://github.com/chenkasirer>`_
* Gonzalo Casas <casas@arch.ethz.ch> `@gonzalocasas <https://github.com/gonzalocasas>`_
* Jonas Haldemann <haldemann@arch.ethz.ch> `@jonashaldemann <https://github.com/jonashaldemann>`_
* Oliver Appling Bucklin <bucklin@arch.ethz.ch> `@obucklin <https://github.com/obucklin>`_
